export class Main extends Indicator {

    constructor() {
        super();

        this.setProperty(Property.SeparateWindow, true);

        this.addInput("FastMA", InputType.int, 4);
        this.addInput("MiddleMA", InputType.int, 9);
        this.addInput("SlowMA", InputType.int, 18);
        this.addInput("TypeMA", InputType.int, 0);
        this.addInput("AppliedPrice", InputType.AppliedPrice, AppliedPrice.Close);

        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffers = {
            WASOMBuffer : this.addBuffer(),
            DFMABuffer : this.addBuffer()
        };
    }

    onInit() {
        let {FastMA, MiddleMA, SlowMA} = this.getInputs();

        this.buffers.WASOMBuffer
            .setShape(Shape.Histogram)
            .setLabel("WASOM")
            .setWidth(1)
            .setColor(Color.Blue)
            .setShortName("RCFMA (" + FastMA + "," + MiddleMA + "," + SlowMA + ")")
            .setDigits(Current.Digits+1)

        this.buffers.DFMABuffer
            .setShape(Shape.Line)
            .setDrawBegin(SlowMA)
            .setLabel("DFMA")
            .setDrawingStyle(DrawingStyle.Solid)
            .setWidth(1)
            .setColor(Color.Red)
            .setShortName("RCFMA (" + FastMA + "," + MiddleMA + "," + SlowMA + ")")
            .setDigits(Current.Digits+1)
        ;
    }

    async onUpdate() {
        const  {FastMA, MiddleMA, SlowMA, TypeMA, AppliedPrice, PriceType} = this.getInputs(),
            {WASOMBuffer, DFMABuffer} = this.buffers;

        let limit, countedBars = Bar.counted(), i, list1, list2,
            barSize = await Bar.size();

        if (countedBars > 0) countedBars--;
        limit = barSize - countedBars;

        list1 = await Indicators.MA(null, 0, MiddleMA, 0, TypeMA, AppliedPrice, PriceType);
        list2 = await Indicators.MA(null, 0, SlowMA, 0, TypeMA, AppliedPrice, PriceType);


        for (i = 0; i < limit; i++) {
            WASOMBuffer.set(i, (list1[i] || 0) - (list2[i] || 0));
        }
        list1 = await Indicators.MA(null, 0, FastMA, 0, TypeMA, AppliedPrice, PriceType);
        for (i = 0; i < limit; i++) {
            DFMABuffer.set(i, (list1[i] || 0) - (list1[i + 1] || 0));
        }


    }
}